==> nextcloud-app-news-1:25.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Užklausa nepavyko, tinklo ryšys neprieinamas!",
    "Request unauthorized. Are you logged in?" : "Užklausa neleidžiama. Ar esate prisijungę?",
    "Request forbidden. Are you an administrator?" : "Užklausa draudžiama. Ar esate administratorius?",
    "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
    "News feeds" : "Naujienų kanalai",
    "Unread articles" : "Neskaityti straipsniai",
    "News" : "Naujienos",
    "News folders" : "Naujienų aplankai",
    "News articles" : "Naujienų straipsniai",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Web address" : "Saityno adresas",
    "No folder" : "Be aplanko",
    "Folder name" : "Aplanko pavadinimas",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Feed exists already!" : "Kanalas jau yra!",
    "New folder" : "Naujas aplankas",
    "Folder exists already!" : "Aplankas jau yra!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Credentials" : "Prisijungimo duomenys ",
    "Subscribe" : "Prenumeruoti",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "Update interval" : "Atnaujinimo intervalas",
    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Please select an article from the list..." : "Pasirinkite straipsnį iš sąrašo...",
    "Move feed to folder" : "Perkelti kanalą į aplanką",
    "Move" : "Perkelti",
    "User Name" : "Naudotojo vardas",
    "Share" : "Bendrinti",
    "Share with" : "Bendrinti su",
    "Mark read" : "Žymėti kaip skaitytą",
    "All articles" : "Visi straipsniai",
    "Starred" : "Pažymėti žvaigždute",
    "Explore" : "Išvalgyti",
    "Settings" : "Nustatymai",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Compact view" : "Rodyti tik antraštes",
    "Show all articles" : "Rodyti visus straipsnius",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
    "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
    "Rename Folder" : "Pervadinti aplanką",
    "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Open Feed URL" : "Atverti kanalo URL",
    "Rename Feed" : "Pervadinti kanalą",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
    "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Close details" : "Užverti išsamesnę informaciją",
    "by" : " ",
    "from" : "iš",
    "shared by" : "bendrina",
    "Play audio" : "Atkurti garso įrašą",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Open website" : "Atverti svetainę",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "{num} seconds" : "{num} sek.",
    "{num} minutes ago" : "prieš {num} min.",
    "{num} hours ago" : "prieš {num} val.",
    "{num} days ago" : "prieš {num} d.",
    "{num} months ago" : "prieš {num} mėn.",
    "{num} years ago" : "prieš {num} m.",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Action" : "Veiksmas",
    "right" : "dešinė",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "left" : "kairė",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "Star article and jump to next one" : "Pažymėti straipsnį ir peršokti prie kito",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Refresh" : "Įkelti iš naujo",
    "Load next feed" : "Įkelti kitą kanalą",
    "Load previous feed" : "Įkelti ankstesnį kanalą",
    "Load previous folder" : "Įkelti ankstesnį aplanką",
    "Load next folder" : "Įkelti kitą aplanką",
    "Scroll to active navigation entry" : "Slinkti į aktyvų naršymo įrašą",
    "Shift" : "Lyg2",
    "All Articles" : "Visi straipsniai",
    "Subscribe to" : "Prenumeruoti",
    "Unread Articles" : "Neskaityti straipsniai",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API",
    "No articles available" : "Nėra straipsnių",
    "No unread articles available" : "Nėra neperskaitytų straipsnių",
    "Star article" : "Pažymėti straipsnį žvaigždute",
    "Unstar article" : "Nebežymėti straipsnio žvaigždute",
    "Share with users" : "Bendrinti su naudotojais",
    "No users found" : "Nerasta jokių naudotojų",
    "Error while searching for users" : "Klaida ieškant naudotojų",
    "Share on social media" : "Bendrinti socialiniuose tinkluose",
    "I wanted you to see this article" : "Norėjau, kad pamatytum šį straipsnį",
    "Check out this article" : "Perskaityk šį straipsnį",
    "Description" : "Aprašas",
    "Mark current article's feed/folder read" : "Žymėti esamo straipsnio kanalą/aplanką kaip skaitytą",
    "Folder" : "Aplankas",
    "Go back" : "Grįžti",
    "New Folder" : "Naujas aplankas",
    "Create" : "Sukurti",
    "Update failed more than 50 times" : "Atnaujinimas daugiau kaip 50 kartų patyrė nesėkmę",
    "Deleted feed" : "Ištrintas kanalas",
    "Undo delete feed" : "Atšaukti kanalo ištrynimą",
    "Menu" : "Meniu",
    "Open feed URL" : "Atverti kanalo URL",
    "Dismiss" : "Pašalinti",
    "Collapse" : "Suskleisti",
    "Deleted folder" : "Ištrintas aplankas",
    "Undo delete folder" : "Atšaukti aplanko ištrynimą",
    "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
    "Subscriptions (OPML)" : "Prenumeratos (OPML)",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Error when importing: File does not contain valid OPML" : "Klaida importuojant: Faile nėra tinkamo OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Klaida, importuojant: OPML faile nėra nei kanalų, nei aplankų",
    "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
    "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
    "Help" : "Pagalba",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pranešti apie klaidą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-news-1:25.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Užklausa nepavyko, tinklo ryšys neprieinamas!",
    "Request unauthorized. Are you logged in?" : "Užklausa neleidžiama. Ar esate prisijungę?",
    "Request forbidden. Are you an administrator?" : "Užklausa draudžiama. Ar esate administratorius?",
    "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
    "News feeds" : "Naujienų kanalai",
    "Unread articles" : "Neskaityti straipsniai",
    "News" : "Naujienos",
    "News folders" : "Naujienų aplankai",
    "News articles" : "Naujienų straipsniai",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Unknown error!" : "Nežinoma klaida!",
    "Web address" : "Saityno adresas",
    "No folder" : "Be aplanko",
    "Folder name" : "Aplanko pavadinimas",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Feed exists already!" : "Kanalas jau yra!",
    "New folder" : "Naujas aplankas",
    "Folder exists already!" : "Aplankas jau yra!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Credentials" : "Prisijungimo duomenys ",
    "Subscribe" : "Prenumeruoti",
    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "Update interval" : "Atnaujinimo intervalas",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Article list" : "Straipsnių sąrašas",
    "Article details" : "Išsamiau apie straipsnį",
    "Please select an article from the list..." : "Pasirinkite straipsnį iš sąrašo...",
    "Move" : "Perkelti",
    "User Name" : "Naudotojo vardas",
    "Share" : "Bendrinti",
    "Share with" : "Bendrinti su",
    "Default" : "Numatytasis",
    "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
    "Rename Folder" : "Pervadinti aplanką",
    "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
    "Mark read" : "Žymėti kaip skaitytą",
    "All articles" : "Visi straipsniai",
    "Starred" : "Pažymėti žvaigždute",
    "Explore" : "Išvalgyti",
    "Settings" : "Nustatymai",
    "Documentation" : "Dokumentacija",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Show all articles" : "Rodyti visus straipsnius",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Rename Feed" : "Pervadinti kanalą",
    "Open Feed URL" : "Atverti kanalo URL",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
    "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
    "Previous Item" : "Ankstesnis elementas",
    "Previous" : "Ankstesnis",
    "Next Item" : "Kitas elementas",
    "Next" : "Kitas",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Close details" : "Užverti išsamesnę informaciją",
    "by" : " ",
    "from" : "iš",
    "shared by" : "bendrina",
    "Play audio" : "Atkurti garso įrašą",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "{num} seconds" : "{num} sek.",
    "{num} minutes ago" : "prieš {num} min.",
    "{num} hours ago" : "prieš {num} val.",
    "{num} days ago" : "prieš {num} d.",
    "{num} months ago" : "prieš {num} mėn.",
    "{num} years ago" : "prieš {num} m.",
    "Open website" : "Atverti svetainę",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Last update" : "Paskutinis atnaujinimas",
    "Next update" : "Kitas atnaujinimas",
    "Title" : "Pavadinimas",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Action" : "Veiksmas",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "right" : "dešinė",
    "left" : "kairė",
    "Star article and jump to next one" : "Pažymėti straipsnį ir peršokti prie kito",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Refresh" : "Įkelti iš naujo",
    "Load next feed" : "Įkelti kitą kanalą",
    "Load previous feed" : "Įkelti ankstesnį kanalą",
    "Load previous folder" : "Įkelti ankstesnį aplanką",
    "Load next folder" : "Įkelti kitą aplanką",
    "Scroll to active navigation entry" : "Slinkti į aktyvų naršymo įrašą",
    "Shift" : "Lyg2",
    "All Articles" : "Visi straipsniai",
    "Subscribe to" : "Prenumeruoti",
    "Unread Articles" : "Neskaityti straipsniai",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API",
    "No articles available" : "Nėra straipsnių",
    "No unread articles available" : "Nėra neperskaitytų straipsnių",
    "Star article" : "Pažymėti straipsnį žvaigždute",
    "Unstar article" : "Nebežymėti straipsnio žvaigždute",
    "Share with users" : "Bendrinti su naudotojais",
    "No users found" : "Nerasta jokių naudotojų",
    "Error while searching for users" : "Klaida ieškant naudotojų",
    "Share on social media" : "Bendrinti socialiniuose tinkluose",
    "I wanted you to see this article" : "Norėjau, kad pamatytum šį straipsnį",
    "Check out this article" : "Perskaityk šį straipsnį",
    "Description" : "Aprašas",
    "Mark current article's feed/folder read" : "Žymėti esamo straipsnio kanalą/aplanką kaip skaitytą",
    "Folder" : "Aplankas",
    "Go back" : "Grįžti",
    "New Folder" : "Naujas aplankas",
    "Create" : "Sukurti",
    "Update failed more than 50 times" : "Atnaujinimas daugiau kaip 50 kartų patyrė nesėkmę",
    "Deleted feed" : "Ištrintas kanalas",
    "Undo delete feed" : "Atšaukti kanalo ištrynimą",
    "Menu" : "Meniu",
    "Open feed URL" : "Atverti kanalo URL",
    "Dismiss" : "Pašalinti",
    "Collapse" : "Suskleisti",
    "Deleted folder" : "Ištrintas aplankas",
    "Undo delete folder" : "Atšaukti aplanko ištrynimą",
    "Compact view" : "Rodyti tik antraštes",
    "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
    "Subscriptions (OPML)" : "Prenumeratos (OPML)",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Error when importing: File does not contain valid OPML" : "Klaida importuojant: Faile nėra tinkamo OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Klaida, importuojant: OPML faile nėra nei kanalų, nei aplankų",
    "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
    "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
    "Help" : "Pagalba",
    "Report a bug" : "Pranešti apie klaidą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
